@@ -275,7 +275,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         break;
                     case 'upload':
                         button = this._makeUploadButton(cfg, btCfg, getFormData,
-                            buttonClass == qx.ui.tolbar.Button
+                            buttonClass == qx.ui.toolbar.Button
                                 ? qx.ui.toolbar.FileSelectorButton
                                 : qx.ui.form.FileSelectorButton);
                         mmButton = this._makeUploadButton(cfg, btCfg, getFormData,
@@ -491,7 +491,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     menuButton.addListener('execute', action, this);
                     tm.add(menuButton);
                 }
-                if (button && manuButton) {
+                if (button && menuButton) {
                     this._bindButtonProperties(button, mmButton);
                 }
             }, this);
@@ -598,6 +598,11 @@ qx.Class.define("callbackery.ui.plugin.Action", {
         },
         getButtonSetMap() {
             return this._buttonSetMap;
+        },
+        _bindButtonProperties(button, mmButton) {
+            ['visibility', 'enabled', 'label', 'icon'].forEach((prop) => {
+                button.bind(prop, mmButton, prop);
+            });
         }
     },
 
@@ -609,9 +614,5 @@ qx.Class.define("callbackery.ui.plugin.Action", {
             btn.destroy();
         }
     },
-    _bindButtonProperties(button, mmButton) {
-        ['visibility', 'enabled', 'label', 'icon'].forEach((prop) => {
-            button.bind(prop, mmButton, prop);
-        });
-    }
+    
 });
